package org.jboss.soa.modeshape.qa.tests.performance;

import java.io.File;
import java.io.FileWriter;
import java.io.PrintWriter;

import javax.jcr.PathNotFoundException;
import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.jboss.soa.esb.qa.framework.Timer;
import org.jboss.soa.modeshape.jcr.client.RepositoryReferenceFactory;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;

public abstract class AbstractPerformanceTest {

	protected Session writeSession;
	protected Session readSession;
	protected int batchSize;
	protected int testCount;
	protected PrintWriter results;

	@BeforeClass
	public void initPerformanceTest() throws Exception {
		writeSession = getSession();
		readSession = getSession();
		batchSize = 10;
		testCount = 500;
		final File file = new File(System.getProperty("test.output"),
				"performance-" + this.getClass().getSimpleName() + ".log");
		results = new PrintWriter(file);
		results.println("Count;Write time;Read Time");
	}

	public Session getSession() throws RepositoryException {
		return RepositoryReferenceFactory.getRepository("repository").login();
	}

	@AfterClass
	public void cleanAfterPerformanceTest() throws Exception {
		writeSession.logout();
		readSession.logout();
		results.close();
	}

	public void logResults(int batchNo, long writeTime, long readTime) {
		System.out.println("Count = " + batchNo * batchSize + ", Write time = "
				+ writeTime + ", Read Time = " + readTime);
		results.println(batchNo * batchSize + ";" + writeTime + ";" + readTime);
	}

	protected long readNode(String lastName) throws RepositoryException,
			PathNotFoundException {
		Timer readTimer = new Timer();
		Session readSession = getSession();
		readTimer.reset();
		readSession.getNode(lastName);
		long readTime = readTimer.elapsed();
		readSession.logout();
		return readTime;
	}

}
